using System;

namespace Syntriax.Engine.Core.Abstract;

/// <summary>
/// Indicates the object is an <see cref="IAssignable"/> with an assignable <see cref="ISprite"/> field.
/// </summary>
public interface IAssignableSprite : IAssignable
{
    /// <summary>
    /// Callback triggered when the <see cref="ISprite"/> value has has been assigned a new value.
    /// </summary>
    Action<IAssignableSprite>? OnSpriteAssigned { get; set; }

    /// <inheritdoc cref="ISprite" />
    ISprite Sprite { get; }

    /// <summary>
    /// Assign a value to the <see cref="ISprite"/> field of this object
    /// </summary>
    /// <param name="sprite">New <see cref="ISprite"/> to assign.</param>
    /// <returns> 
    /// <see cref="true"/>, if the value given assigned successfully assigned, <see cref="false"/> if not.
    /// </returns>
    bool Assign(ISprite sprite);
}
